@@ -17,10 +17,8 @@
 
 namespace APP\plugins\generic\orcidProfile;
 use APP\issue\Issue;
-use APP\journal\Journal;
 use APP\plugins\generic\citationStyleLanguage\CitationStyleLanguagePlugin;
 use APP\publication\Publication;
-
 use APP\author\Author;
 use APP\controllers\grid\users\author\form\AuthorForm;
 use APP\core\Application;
@@ -43,6 +41,7 @@ use PKP\components\forms\FieldOptions;
 use PKP\components\forms\FieldText;
 use PKP\components\forms\publication\ContributorForm;
 use PKP\config\Config;
+use PKP\context\Context;
 use PKP\core\Core;
 use PKP\core\JSONMessage;
 use PKP\core\PKPApplication;
@@ -98,6 +97,16 @@ class OrcidProfilePlugin extends GenericPlugin
         if ($success && $this->getEnabled($mainContextId)) {
             $contextId = ($mainContextId === null) ? $this->getCurrentContextId() : $mainContextId;
 
+            $validator = new OrcidValidator($this);
+
+            $clientId = $this->getSetting($contextId, 'orcidClientId');
+            $clientSecret = $this->getSetting($contextId, 'orcidClientSecret');
+
+            if (!$validator->validateClientSecret($clientSecret) || !$validator->validateClientId($clientId)) {
+                error_log(new Exception('The ORCID plugin is enabled, but its settings are invalid. In order to fix, access the plugin settings and try to save the form'));
+                return $success;
+            }
+
             Hook::add('ArticleHandler::view', [&$this, 'submissionView']);
             Hook::add('PreprintHandler::view', [&$this, 'submissionView']);
 
@@ -260,7 +269,15 @@ class OrcidProfilePlugin extends GenericPlugin
                 return parent::getSetting($contextId, $name);
         }
 
-        return $config_value ?: parent::getSetting($contextId, $name);
+        $config_value = $config_value ?? parent::getSetting($contextId, $name);
+        if ($name == 'orcidProfileAPIPath') {
+            if ($config_value == 'https://orcid.org/') {
+                $config_value = ORCID_API_URL_PUBLIC;
+            } elseif ($config_value == 'https://sandbox.orcid.org/') {
+                $config_value = ORCID_API_URL_PUBLIC_SANDBOX;
+            }
+        }
+        return $config_value;
     }
 
     /**
@@ -345,6 +362,12 @@ class OrcidProfilePlugin extends GenericPlugin
      */
     public function publishReviewerWorkToOrcid(Submission $submission, Request $request)
     {
+        // Application is set to sandbox mode and will not run the features of plugin
+        if (Config::getVar('general', 'sandbox', false)) {
+            error_log('Application is set to sandbox mode and will not have any interaction with orcid service');
+            return new JSONMessage(false, __('common.sandbox'));
+        }
+
         $context = $request->getContext();
         $requestVars = $request->getUserVars();
         /** @var ReviewAssignmentDAO */
@@ -381,6 +404,7 @@ class OrcidProfilePlugin extends GenericPlugin
                             [
                                 'headers' => $headers,
                                 'json' => $orcidReview,
+                                'allow_redirects' => ['strict' => true],
                             ]
                         );
                     } catch (ClientException $exception) {
@@ -413,7 +437,7 @@ class OrcidProfilePlugin extends GenericPlugin
 
     public function buildOrcidReview($submission, $review, $request, $issue = null)
     {
-        $publicationUrl = $request->getDispatcher()->url($request, PKPApplication::ROUTE_PAGE, null, 'article', 'view', $submission->getId());
+        $publicationUrl = $request->getDispatcher()->url($request, PKPApplication::ROUTE_PAGE, null, $this->getAppSpecificUrlHandlerName(), 'view', $submission->getId());
         $context = $request->getContext();
         $publicationLocale = ($submission->getData('locale')) ? $submission->getData('locale') : 'en';
         $pubIdPlugins = PluginRegistry::loadCategory('pubIds', true, $context->getId()); // DO not remove
@@ -457,9 +481,16 @@ class OrcidProfilePlugin extends GenericPlugin
                 $orcidReview['subject-url'] = ['value' => $publicationUrl];
                 $orcidReview['review-url'] = ['value' => $publicationUrl];
                 $orcidReview['subject-type'] = 'journal-article';
-                $orcidReview['subject-name'] = [
-                    'title' => ['value' => $submission->getCurrentPublication()->getLocalizedData('title') ?? '']
-                ];
+
+                $allTitles = $submission->getCurrentPublication()->getData('title');
+                $submissionLocale = $submission->getData('locale');
+                foreach ($allTitles as $locale => $title) {
+                    if ($locale === $submissionLocale) {
+                        $orcidReview['subject-name']['title'] = ['value' => $title];
+                    } else {
+                        $orcidReview['subject-name']['translated-title'] = ['value' => $title, 'language-code' => substr($locale, 0, 2)];
+                    }
+                }
 
 
                 if (!empty($submission->getData('pub-id::doi'))) {
@@ -477,17 +508,6 @@ class OrcidProfilePlugin extends GenericPlugin
                 }
             }
 
-            $translatedTitleAvailable = false;
-            foreach ($supportedSubmissionLocales as $defaultLanguage) {
-                if ($defaultLanguage !== $publicationLocale) {
-                    $iso2LanguageCode = substr($defaultLanguage, 0, 2);
-                    $defaultTitle = $submission->getLocalizedData($iso2LanguageCode);
-                    if (strlen($defaultTitle) > 0 && !$translatedTitleAvailable) {
-                        $orcidReview['subject-name']['translated-title'] = ['value' => $defaultTitle, 'language-code' => $iso2LanguageCode];
-                        $translatedTitleAvailable = true;
-                    }
-                }
-            }
             return $orcidReview;
         }
     }
@@ -609,6 +629,27 @@ class OrcidProfilePlugin extends GenericPlugin
         return false;
     }
 
+    /**
+     * Output filter adds ORCiD interaction to contributors metadata add/edit form.
+     *
+     * @param $output string
+     * @param $templateMgr TemplateManager
+     * @return string
+     */
+    function authorFormFilter($output, $templateMgr) {
+        if (preg_match('/<input[^>]+name="submissionId"[^>]*>/', $output, $matches, PREG_OFFSET_CAPTURE)) {
+            $match = $matches[0][0];
+            $offset = $matches[0][1];
+            $templateMgr->assign('orcidIcon', $this->getIcon());
+            $newOutput = substr($output, 0, $offset + strlen($match));
+            $newOutput .= $templateMgr->fetch($this->getTemplateResource('authorFormOrcid.tpl'));
+            $newOutput .= substr($output, $offset + strlen($match));
+            $output = $newOutput;
+            $templateMgr->unregisterFilter('output', [$this, 'authorFormFilter']);
+        }
+        return $output;
+    }
+
     /**
      * Hook callback: register output filter for user registration and article display.
      *
@@ -1059,29 +1100,6 @@ class OrcidProfilePlugin extends GenericPlugin
         return __('plugins.generic.orcidProfile.displayName');
     }
 
-    public function setEnabled($enabled)
-    {
-        $contextId = $this->getCurrentContextId();
-        $request = Application::get()->getRequest();
-        $validator = new OrcidValidator($this);
-
-        if ($this->isSitePlugin()) {
-            $contextId = 0;
-        }
-        if ($request->getUserVar('save') == 1) {
-            $clientId = $request->getUserVar('orcidClientId');
-            $clientSecret = $request->getUserVar('orcidClientSecret');
-        } else {
-            $clientId = $this->getSetting($contextId, 'orcidClientId');
-            $clientSecret = $this->getSetting($contextId, 'orcidClientSecret');
-        }
-
-        if (!$validator->validateClientSecret($clientSecret) or !$validator->validateClientId($clientId)) {
-            $enabled = false;
-        }
-        $this->updateSetting($contextId, 'enabled', $enabled, 'bool');
-    }
-
     public function manage($args, $request)
     {
         $context = $request->getContext();
@@ -1090,7 +1108,7 @@ class OrcidProfilePlugin extends GenericPlugin
         switch ($request->getUserVar('verb')) {
             case 'settings':
 
-                $templateMgr = TemplateManager::getManager();
+                $templateMgr = TemplateManager::getManager($request);
                 $templateMgr->registerPlugin('function', 'plugin_url', [$this, 'smartyPluginUrl']);
 
                 $templateMgr->assign('orcidApiUrls', [
@@ -1171,6 +1189,12 @@ class OrcidProfilePlugin extends GenericPlugin
      **/
     public function sendSubmissionToOrcid($publication, $request)
     {
+        // Application is set to sandbox mode and will not run the features of plugin
+        if (Config::getVar('general', 'sandbox', false)) {
+            error_log('Application is set to sandbox mode and will not have any interaction with orcid service');
+            return new JSONMessage(false, __('common.sandbox'));
+        }
+
         $context = $request->getContext();
         $contextId = $this->currentContextId = $context->getId();
         $publicationId = $publication->getId();
@@ -1247,6 +1271,7 @@ class OrcidProfilePlugin extends GenericPlugin
                     [
                         'headers' => $headers,
                         'json' => $orcidWork,
+                        'allow_redirects' => ['strict' => true],
                     ]
                 );
             } catch (ClientException $exception) {
@@ -1317,7 +1342,7 @@ class OrcidProfilePlugin extends GenericPlugin
      *  Example of valid ORCID JSON for adding works to an ORCID record.
      *
      * @param Publication $publication extract data from this Article
-     * @param Journal $context Context object the Submission is part of
+     * @param Context $context Context object the Submission is part of
      * @param Author[] $authors Array of Author objects, the contributors of the publication
      * @param Issue $issue Issue the Article is part of
      * @param Request $request the current request
@@ -1334,7 +1359,7 @@ class OrcidProfilePlugin extends GenericPlugin
         $publicationLocale = ($publication->getData('locale')) ? $publication->getData('locale') : 'en';
         $supportedSubmissionLocales = $context->getSupportedSubmissionLocales();
 
-        $publicationUrl = $request->getDispatcher()->url($request, Application::ROUTE_PAGE, null, 'article', 'view', $submission->getId());
+        $publicationUrl = $request->getDispatcher()->url($request, Application::ROUTE_PAGE, null, $this->getAppSpecificUrlHandlerName(), 'view', $submission->getId());
 
         $orcidWork = [
             'title' => [
@@ -1397,7 +1422,7 @@ class OrcidProfilePlugin extends GenericPlugin
      *
      * @param Submission $submission The Article object for which the external identifiers should be build.
      * @param Publication $publication The Article object for which the external identifiers should be build.
-     * @param Journal $context Context the Submission is part of.
+     * @param Context $context Context the Submission is part of.
      * @param Issue $issue The Issue object the Article object belongs to.
      *
      * @return array            An associative array corresponding to ORCID external-id JSON.
@@ -1682,4 +1707,16 @@ class OrcidProfilePlugin extends GenericPlugin
 
         return false;
     }
+
+    /**
+     * Gets the correct application-specific URL handler name for generating publication URLs
+     */
+    private function getAppSpecificUrlHandlerName(): string
+    {
+        $appName = Application::get()->getName();
+        return match ($appName) {
+            'ops' => 'preprint',
+            default => 'article',
+        };
+    }
 }
